local beql = beql
local L = AceLibrary("AceLocale-2.2"):new("beql")

function beql:InitTooltip()
	if beqlQ then
		self:HookScript(GameTooltip, "OnTooltipSetUnit", "GameTooltip_OnTooltipSetUnit")
		self:HookScript(GameTooltip, "OnTooltipSetItem", "GameTooltip_OnTooltipSetItem")
	end
	-- Init Tracker Tooltips
	
	QuestWatchFrame:SetScript("OnMouseDown", function() if not beql.db.char.saved.minimizedtracker then beql:TrackerClick() end end)
	QuestWatchFrame:SetScript("OnUpdate", function() 
		if not MouseIsOver(QuestWatchFrame) and beql.db.char.saved.tooltipset then
			ResetCursor()
			GameTooltip:FadeOut()
			beql.db.char.saved.tooltipset = false
		end	
		if MouseIsOver(QuestWatchFrame) then 
			beql:TrackerTooltip() 
		end 
	end)	
end

function beql:GameTooltip_OnTooltipSetUnit(this, ...)
	self.hooks[this].OnTooltipSetUnit(this, ...)
	if beql.db.profile.tooltipmob then
		local queryString = GameTooltip:GetUnit()
		if queryString then
			if beqlQ:IsQuestMob(queryString) then
				beql:ScanTooltipItem(queryString)
			end
		end
	end
end

function beql:GameTooltip_OnTooltipSetItem(this, ...)
	self.hooks[this].OnTooltipSetItem(this, ...)
	if beql.db.profile.tooltipitem then
		queryString = GameTooltip:GetItem()
		local _, _, numberNeeded = beqlQ:IsQuestItem(queryString)
		if numberNeeded then 
			beql:ScanTooltipItem(queryString)
		end
	end
end

function beql:ScanTooltipItem(queryString)
	for questID, questTitle, questLevel, questTag, questGroup, questComplete, questNumObjectives, questZone in beqlQ:IterateQuests() do
		for objIndex = 1,questNumObjectives do 
			objDescription, objType, objPossessed, objNeeded, objComplete = beqlQ:GetQuestStatusById(questID,objIndex)
			if objDescription == queryString then 
				if questGroup > 0 then
					questPrefix = questLevel.."G"..questGroup
				else
					questPrefix = questLevel
				end
				GameTooltip:AddDoubleLine("["..questPrefix.."]"..questTitle,objPossessed.."/"..objNeeded,GetDifficultyColor(questLevel).r,GetDifficultyColor(questLevel).g,GetDifficultyColor(questLevel).b)
			end
		end
	end
	GameTooltip:Show()
end

function beql:TrackerClick()
		if QuestWatchFrame.ismoving then
			return
		end
		if(not beql.db.char.saved.CurrentHoveredQuest and beql.db.char.saved.CurrentHoveredQuest <= 0) then
			return
		end
		if arg1 == "LeftButton" and beql.db.profile.activetrackerleft then
			SelectQuestLogEntry(beql.db.char.saved.CurrentHoveredQuest)
			if( not QuestLogFrame:IsVisible() ) then
				ShowUIPanel(QuestLogFrame)
			else
				QuestLog_Update()
				QuestLog_UpdateQuestDetails(1)
			end
			if beql.db.char.saved.minimized then 
				beql:Maximize() 
			end
		elseif arg1 == "RightButton" and beql.db.profile.activetrackerright then
			RemoveQuestWatch(beql.db.char.saved.CurrentHoveredQuest)
			QuestLog_Update()		
			QuestWatch_Update()
		end	
end

function beql:TrackerTooltip()
		local qid = 0
		local textline = 0
		local watchLine
		local x, y = GetCursorPosition()
		local s = QuestWatchFrame:GetEffectiveScale()
		x,y = x/s, y/s
	
		for i=1, MAX_QUESTWATCH_LINES, 1 do
			textline = textline + 1
			watchLine = getglobal("QuestWatchLine"..i)
			if ( watchLine:IsVisible() ) then
				local l, r, t, b = watchLine:GetLeft(), watchLine:GetRight(), watchLine:GetTop(), watchLine:GetBottom()
				if ( x <= r and x >= l and y <= t and y >= b ) then
					break;
				end
			end
		end
		if beql.db.char.TrackerQuests[textline] then
			ResetCursor()
			ShowInspectCursor()	
			qid = beql.db.char.TrackerQuests[textline]
			local oldSelection = GetQuestLogSelection()
			SelectQuestLogEntry(qid)
			local _, questObjectives = GetQuestLogQuestText()
			SelectQuestLogEntry(oldSelection)
			beql.db.char.saved.CurrentHoveredQuest = qid
			local qTitle,qLvl,qTag,qRec,qStat,qObj,qZone,qID = beqlQ:GetQuest(qid)
			Color = GetDifficultyColor(qLvl)
			if beql.db.profile.activetracker then
				GameTooltip:SetOwner(QuestWatchFrame, "ANCHOR_CURSOR")
				GameTooltip:AddLine(qTitle,Color.r,Color.g,Color.b)
				if beql.db.profile.activetrackerdesc then
					GameTooltip:AddLine(questObjectives,1.0,0.8,0,1)		
				end
				if beql.db.profile.activetrackerparty then
					-- Party Quest Status (not implemented yet)
				end
				GameTooltip:Show()
				beql.db.char.saved.tooltipset = true		
			end
		else
			if beql.db.char.saved.tooltipset then
				ResetCursor()
				GameTooltip:FadeOut()
				beql.db.char.saved.tooltipset = false
			end		
		end
end